@@ -10,14 +10,11 @@
 //
 //
 
-#include "packagesearchimpl.h"
 
-#include <iostream>
 #include <algorithm>
 #include <functional>
 #include <cassert>
 
-
 #include <qaction.h>
 #include <QApplication>
 #include <qclipboard.h>
@@ -39,9 +36,11 @@
 #include <QToolBar>
 #include <QWhatsThis>
 
+#include "packagesearchimpl.h"
+
 // NApplication
-#include "applicationfactory.h"
 #include "runcommand.h"
+#include "runcommandforparsing.h"
 #include "gainroot.h"
 
 // namespace NPlugin 
@@ -70,13 +69,6 @@
 // NUtil
 #include "helpers.h"
 
-#undef slots
-#include <xapian.h>
-
-#include <ept/apt/apt.h>
-#include <ept/debtags/debtags.h>
-#include <ept/debtags/vocabulary.h>
-#include <ept/axi/axi.h>
 
 
 using namespace std;
@@ -112,9 +104,6 @@ PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::Win
 	setObjectName(name);
 	setupUi(this);
 
-	_pApt = 0;
-	_pVocabulary = 0;
-	_pXapianDatabase = 0;
 	// set up what's this actions
 	_pWhatsThisAction = QWhatsThis::createAction(this);
 	_pWhatsThisAction->setShortcut(QKeySequence("Shift+F1"));
@@ -183,12 +172,8 @@ PackageSearchImpl::~PackageSearchImpl()
 {
 	delete _pPackageNamePlugin;
 	delete _pScoreDisplayPlugin;
-	delete _pApt;
-	delete _pVocabulary;
-	delete _pXapianDatabase;
 }
 
-
 /////////////////////////////////////////////////////
 // Initialisation
 /////////////////////////////////////////////////////
@@ -245,32 +230,7 @@ void PackageSearchImpl::initMenus()
 
 void PackageSearchImpl::initialize()
 {
-
-	_pApt = new ept::apt::Apt;
-	_pVocabulary = new ept::debtags::Vocabulary;
-	// TODO: check if the database is up-to-date (though 
-	// apt-xapian-index by default updates the index after installation and weekly
-	bool success = false;
-	// try running until Xapian::Database can be constructed
-	do 
-	{
-		try {
-			_pXapianDatabase = new Xapian::Database("/var/lib/apt-xapian-index/index");
-			success = true;
-		} catch (Xapian::RuntimeError& e) {
-			if ( QMessageBox::critical(this, tr("Error trying to open Xapian database"), 
-					tr("<p>An error occurred trying to open the xapian database at "
-						"/var/lib/apt-xapian-index/index please make sure the file is "
-						"readable and valid. You may try to run update-apt-xapian-index "
-						"to fix this problem. The orginal error message was:<br>\"") +
-					toQString(e.get_msg()) + "\"</p>" + 
-					tr("Would you like to run update-apt-xapian-index now? Otherwise "
-						"packagesearch will be terminated."), QMessageBox::Yes, QMessageBox::No) == QMessageBox::No )
-				exit(2);
-			updateXapianDatabase();
-		}
-	}
-	while (!success);
+    initPackageList();
 
     makeHandleVisible(_pHSplitter->handle(1));
     makeHandleVisible(_pUpperVSplitter->handle(1));
@@ -300,6 +260,12 @@ void PackageSearchImpl::initialize()
 	setPackageActionsEnabled(false);
 }
 
+void PackageSearchImpl::initPackageList() {
+    auto lineProcessor = [this](const std::string& line) {
+        _packages.insert(line);
+    };
+    NApplication::runCommandForParsing("apt-cache pkgnames", lineProcessor);
+}
 
 /////////////////////////////////////////////////////
 // IXmlStorable Interface
@@ -481,25 +447,9 @@ NUtil::IProgressObserver* PackageSearchImpl::progressObserver() const
 
 const set<string>& PackageSearchImpl::packages() const
 {
-	static bool initialized = false;
-	if (!initialized)
-	{	
-		typedef ept::apt::Apt Apt;
-		initialized = true;
-		for (Apt::Iterator it = _pApt->begin(); it != _pApt->end(); ++it)
-		{
-			_packages.insert(*it);
-		}
-	}
 	return _packages;
 }
 
-void PackageSearchImpl::reloadAptFrontCache()
-{
-	delete _pApt;
-	_pApt = new ept::apt::Apt;
-}
-
 QNetworkAccessManager* PackageSearchImpl::network() 
 {
     return _pNetworkAccessManager;
@@ -841,14 +791,16 @@ void PackageSearchImpl::updatePackageInformation(const QString & package)
 					detailedText += pPlugin->informationText(toString(package));
 				}
 				// simply ignore it if the package was not available for this plugin
-				catch (NPlugin::PackageNotFoundException& e) {}
+                catch (NPlugin::PackageNotFoundException& e) {
+                    qWarning() << "PackageNotFoundException " << e.name();
+                }
 				catch (std::exception& e) {
-					qWarning() << "Plugin " << (*it)->name() << " failed to provide detailed information\n"
+                    qWarning() << "Plugin " << (*it)->name() << " failed to provide detailed information\n"
 							<< "e.what(): " << e.what();
 				}
-				catch (...) {
+                catch (...) {
 					qWarning() << "Plugin " << (*it)->name() << " failed to provide detailed information (unknown exception thrown)";
-				}
+                }
 			}
 			if (_pInformationContainer->currentWidget() == pPlugin->informationWidget())
 			{
@@ -1063,29 +1015,6 @@ void PackageSearchImpl::setPackageActionsEnabled(bool enabled)
 		(*it)->setEnabled(enabled);
 }
 
-void PackageSearchImpl::checkAptDbForUpdates()
-{
-	_pApt->checkCacheUpdates();
-}
-
-void PackageSearchImpl::updateXapianDatabase() 
-{
-	setEnabled(false);
-	NApplication::RunCommand* pCommand = NApplication::ApplicationFactory::getInstance()->getRunCommand("");
-	pCommand->addArgument("/usr/sbin/update-apt-xapian-index");
-	pCommand->addArgument("-f");
-	pCommand->startAsRoot();
-	while (!pCommand->finished()) 
-	{
-		pCommand->waitForFinished(500);
- 		qApp->processEvents();
-	}
-	// reload new xapian database
-	delete _pXapianDatabase;
-	_pXapianDatabase = new Xapian::Database(ept::axi::path_db());
-	setEnabled(true);
-}
-
 void PackageSearchImpl::makeHandleVisible(QSplitterHandle* pSplitterHandle) {
     QVBoxLayout *layout = new QVBoxLayout(pSplitterHandle);
     layout->setSpacing(0);
