@@ -12,7 +12,6 @@
 #include "complexscorecalculationstrategy.h"
 
 #include <vector>
-#include <iostream>
 #include <cassert>
 
 
@@ -70,7 +69,7 @@ void ComplexScoreCalculationStrategy::calculateScore(const set<string>& packages
         catch (NPlugin::PackageNotFoundException& e)
 		{
 			qDebug("PackageNotFoundException");
-			setScore(*it, 1.0f);
+            setScore(*it, 0.5f);
 		}
 	}
 	// calculate the scores for each package
@@ -103,12 +102,12 @@ ComplexScoreCalculationStrategy::ScoreInformation
 	ComplexScoreCalculationStrategy::getScoreInformation(const string& package, bool)  const
 {
 	ScoreInformation info(package);
-    auto packageStruct = _pPackageDb->getPackageRecord(package);
+    auto& packageStruct = _pPackageDb->getPackageRecord(package);
 	
 	for (QStringList::const_iterator it = _includePatterns.begin(); it != _includePatterns.end(); ++it)
 	{
-        info.addNameScore(getNameScore(*packageStruct, *it));
-        info.addDescriptionScore(getDescriptionScore(*packageStruct, *it));
+        info.addNameScore(getNameScore(packageStruct, *it));
+        info.addDescriptionScore(getDescriptionScore(packageStruct, *it));
 	}
 	return info;
 }
@@ -148,7 +147,7 @@ float ComplexScoreCalculationStrategy::getNameScore(const IPackage& package, con
 
 float ComplexScoreCalculationStrategy::getDescriptionScore(const IPackage& package, const QString& pattern) const
 {
-    Matches m = findMatches(package.description(), pattern);
+    Matches m = findMatches(package.shortDescription(), pattern);
 	return (m.wholeWordCsMatches * Scores::WHOLE_CS_WORD + m.wholeWordMatches * Scores::WHOLE_WORD
 		+ m.innerMatches * Scores::INNER_MATCH + m.borderMatches * Scores::BORDER_MATCH) / pattern.length();
 }
