@@ -23,7 +23,7 @@ FilenameActionPlugin::FilenameActionPlugin() :
  	_title("Filename-Action Plugin"),
 	_briefDescription("Offers the menu and toolbar entries"),
 	_description("This plugin offers the menu and toolbar entries for the Filename plugin. "
-		"Currently this is only the debtags update entry.")
+        "Currently the only entry is updating the apt-file database.")
 {
 	QAction* pQAptFileUpdateAction = new QAction(QObject::tr("Update File Database"), this);
 	pQAptFileUpdateAction->setStatusTip(tr("Calls \"apt-file update\" updating the file database"));
