@@ -1,25 +1,29 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de">
+<TS version="2.1" language="de_DE">
 <context>
     <name>AptSearchPluginShortInputWidget</name>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="14"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="107"/>
         <source>Form1</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="26"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="108"/>
         <source>Search for pattern</source>
         <translation>Nach Zeichenkette suchen</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="41"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="110"/>
         <source>Search the package database for the given expression</source>
         <translation>Durchsucht die Paketdatenbank nach dem angegebenen Ausdruck</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="52"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="116"/>
         <source>Clear</source>
         <translation>Löschen</translation>
     </message>
@@ -29,16 +33,19 @@
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="76"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="124"/>
         <source>Case Sensitive</source>
-        <translation>Groß-/Kleinschreibung</translation>
+        <translation type="unfinished">roß-/Kleinschreibung</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="85"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="126"/>
         <source>Search the package descriptions</source>
         <translation>Paketbeschreibungen mit durchsuchen</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="91"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="131"/>
         <source>Search Descriptions</source>
         <translation>Beschreibungen durchsuchen</translation>
     </message>
@@ -58,28 +65,32 @@ Jedes nicht-alphanumerische Zeichen wird dabei als Wortgrenze betrachtet.</trans
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="44"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="113"/>
         <source>This searches the package names and descriptions for the given pattern. If you enter more than one word all words must be contained.&lt;br&gt;
 You can search for phrases by using double quotes around the phrase. To enter patterns or phrases which should not appear in the package precede them with a minus (&apos;-&apos;).</source>
-        <translation>Die Paketnamen und -beschreibungen werden nach der eingegebenen Zeichenkette durchsucht. Wird mehr als ein Wort angeben, so müssen alle Wörter gefunden werden.&lt;br&gt;
-Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt werden. Um eine unerwünschte Zeichenkette einzugeben kann ein Minuszeichen &apos;-&apos; vorangestellt werden.</translation>
+        <translation type="unfinished">Die Paketnamen und -beschreibungen werden nach der eingegebenen Zeichenkette durchsucht. Wird mehr als ein Wort angeben, so müssen alle Wörter gefunden werden.</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="63"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="118"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Search for whole words only&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>Nur nach ganzen Wörtern suchen</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="66"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="120"/>
         <source>Whole Words</source>
         <translation>Ganze Wörter</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="73"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="122"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Search case sensitive&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation>Groß-/Kleinschreibung beachten</translation>
+        <translation type="unfinished">roß-/Kleinschreibung beachten</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsearchpluginshortinputwidget.ui" line="88"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsearchpluginshortinputwidget.h" line="129"/>
         <source>Check this if you want to search in the package descriptions. The search will search the package name, the long description and the short description.&lt;br /&gt;If not checked only the package names will be searched.</source>
         <translation>Wenn dieses Kästchen aktiviert ist, werden die Paketbeschreibungen mit durchsucht. Die Suche sucht dann in dem Namen, der ausführlichen und der Kurzbeschreibung. Ansonsten werden nur die Paketnamen durchsucht.</translation>
     </message>
@@ -88,31 +99,37 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
     <name>AptSettingsWidget</name>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="13"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="68"/>
         <source>Form</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="19"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="70"/>
         <source>The selected tool will be used to install/remove the selected packages</source>
         <translation>Das ausgewählte Programm wird zu Installation/Deinstallation von Paketen verwendet</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="22"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="73"/>
         <source>For package installation Debian Package Search relies on an external program. You can select wether to use apt or aptitude here.</source>
         <translation>Zur Installation/Deinstallation von Paketen verwendet die Debian Paketsuche ein externes Programm. Hier kann eingestellt werden welches Programm verwendet werden soll.</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="25"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="75"/>
         <source>Package Administration Tool</source>
         <translation>Programm zur Paketverwaltung</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="31"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="76"/>
         <source>apt-get</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/aptsettingswidget.ui" line="38"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_aptsettingswidget.h" line="77"/>
         <source>aptitude</source>
         <translation type="unfinished"></translation>
     </message>
@@ -121,41 +138,49 @@ Nach Wortgruppen kann gesucht werden, indem diese in Anführungsstriche gesetzt
     <name>InstalledFilterWidget</name>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="13"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="65"/>
         <source>Form1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="25"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="66"/>
         <source>Installed Filter</source>
         <translation>Installationsstatus</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="32"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="73"/>
         <source>Search packages by installed state</source>
         <translation>Pakete anhand ihres Installationsstatuses suchen</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="35"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="76"/>
         <source>Search packages by installed state.</source>
         <translation>Pakete anhand ihres Installationsstatuses suchen.</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="39"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="67"/>
         <source>All</source>
         <translation>Alle</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="44"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="68"/>
         <source>Installed</source>
         <translation>Installiert</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="49"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="69"/>
         <source>Upgradable</source>
         <translation>Aktualisierbar</translation>
     </message>
     <message>
         <location filename="../plugins/aptplugin/installedfilterwidget.ui" line="54"/>
+        <location filename="../plugins/aptplugin/aptplugin_autogen/include/ui_installedfilterwidget.h" line="70"/>
         <source>Not Installed</source>
         <translation>Nicht Installiert</translation>
     </message>
