@@ -1,48 +1,56 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="de">
+<TS version="2.1" language="de_DE">
 <context>
     <name>ChoosenTagsDisplay</name>
     <message>
         <location filename="../plugins/debtagsplugin/choosentagsdisplay.ui" line="13"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_choosentagsdisplay.h" line="68"/>
         <source>Form2</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/choosentagsdisplay.ui" line="34"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_choosentagsdisplay.h" line="69"/>
         <source>Show the packages with all of the tags</source>
-        <translation></translation>
+        <translation>Zeige das Paket und all seine Tags an</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/choosentagsdisplay.ui" line="44"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_choosentagsdisplay.h" line="70"/>
         <source>Exclude packages with any of the tags</source>
-        <translation></translation>
+        <translation>Paket mit diesen Tags ausschließen</translation>
     </message>
 </context>
 <context>
     <name>DebtagsSettingsWidget</name>
     <message>
         <location filename="../plugins/debtagsplugin/debtagssettingswidget.ui" line="13"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_debtagssettingswidget.h" line="115"/>
         <source>Form2</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/debtagssettingswidget.ui" line="41"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_debtagssettingswidget.h" line="116"/>
         <source>Facets Shown</source>
         <translation>Angezeigte Facetten</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/debtagssettingswidget.ui" line="65"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_debtagssettingswidget.h" line="117"/>
         <source>&gt;&gt;</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/debtagssettingswidget.ui" line="72"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_debtagssettingswidget.h" line="118"/>
         <source>&lt;&lt;</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/debtagssettingswidget.ui" line="89"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_debtagssettingswidget.h" line="119"/>
         <source>Facets Hidden</source>
         <translation>Ausgeblendete Facetten</translation>
     </message>
@@ -50,7 +58,7 @@
 <context>
     <name>NPlugin::DebtagsPlugin</name>
     <message>
-        <location filename="../plugins/debtagsplugin/debtagsplugin.cpp" line="168"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin.cpp" line="165"/>
         <source>Performing tag search on package database</source>
         <translation>Führe Facettensuche aus</translation>
     </message>
@@ -77,31 +85,36 @@ Anschließend können Sie den debtags-Plugin unter &quot;Packagesearch&quot; -&g
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/debtagsplugincontainer.cpp" line="111"/>
+        <source>&lt;p&gt;The vocabulary is not available. Usually this appens only if debtags ist not installed.Please install &lt;tt&gt;debtags&lt;/tt&gt; or check your /var/lib/debtags/vocabulary file manually.&lt;/p&gt;The debtags plugin will be disabled for now, you can re-enable it via the Packagesearch menu -&gt; Control Plugins.&lt;/p&gt;</source>
+        <translation>&lt;p&gt;Die Vokabular-Datei fehlt. Normalerweise bedeutet dies, dass das &lt;tt&gt;debtags&lt;/tt&gt;-Paket nicht installiert ist.Bitte installieren sie debtagsoder überprüfen Sie die Datei /var/lib/debtags/vocabulary von Hand.&lt;/p&gt;
+&lt;p&gt;Der Debtags-Plugin wird deaktiviert. Er kann über das Packagesearch Menü unter &quot;Plugins Verwalten&quot; wieder aktiviert werden.&lt;/p&gt;</translation>
+    </message>
+    <message>
         <source>&lt;p&gt;The vocabulary is not available. This should not happen. Please reinstall &lt;tt&gt;debtags&lt;/tt&gt; or check your /var/lib/debtags/vocabulary file manually.&lt;/p&gt;The debtags plugin will be disabled for now, you can re-enable it via the Packagesearch menu -&gt; Control Plugins.&lt;/p&gt;</source>
-        <translation>&lt;p&gt;Die Vokabular-Datei fehlt. Dies sollte nicht vorkommen. Bitte installieren Sie &lt;tt&gt;debtags&lt;/tt&gt; erneut oder überprüfen Sie die Datei /var/lib/debtags/vocabulary von Hand.&lt;/p&gt;
+        <translation type="vanished">&lt;p&gt;Die Vokabular-Datei fehlt. Dies sollte nicht vorkommen. Bitte installieren Sie &lt;tt&gt;debtags&lt;/tt&gt; erneut oder überprüfen Sie die Datei /var/lib/debtags/vocabulary von Hand.&lt;/p&gt;
 &lt;p&gt;Der Debtags-Plugin wird deaktiviert. Er kann über das Packagesearch Menü unter &quot;Plugins Verwalten&quot; wieder aktiviert werden.&lt;/p&gt;</translation>
     </message>
 </context>
 <context>
     <name>NPlugin::RelatedPlugin</name>
     <message>
-        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="60"/>
+        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="61"/>
         <source>Similar Plugin</source>
         <translation>Plugin für Ähnlichkeitssuche</translation>
     </message>
     <message>
-        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="65"/>
-        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="70"/>
+        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="66"/>
+        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="71"/>
         <source>Plugin for searching packages similar to another package.</source>
         <translation>Plugin zum Suchen von Paketen die ähnlich einem anderen sind.</translation>
     </message>
     <message>
-        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="109"/>
+        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="110"/>
         <source>Similar</source>
         <translation>Ähnlich</translation>
     </message>
     <message>
-        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="174"/>
+        <location filename="../plugins/debtagsplugin/relatedplugin.cpp" line="175"/>
         <source>Searching for similar packages</source>
         <translation>Suche nach ähnlichen Paketen</translation>
     </message>
@@ -174,26 +187,31 @@ Anschließend können Sie den debtags-Plugin unter &quot;Packagesearch&quot; -&g
     <name>RelatedFeedbackWidget</name>
     <message>
         <location filename="../plugins/debtagsplugin/relatedfeedbackwidget.ui" line="13"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedfeedbackwidget.h" line="72"/>
         <source>Form2</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedfeedbackwidget.ui" line="25"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedfeedbackwidget.h" line="73"/>
         <source>Search packages similar to</source>
         <translation>Suche Pakete ähnlich zu</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedfeedbackwidget.ui" line="40"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedfeedbackwidget.h" line="75"/>
         <source>displays the package to search related packages for</source>
         <translation>Zeigt das Paket an, zu dem ähnliche Pakete gesucht werden</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedfeedbackwidget.ui" line="43"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedfeedbackwidget.h" line="78"/>
         <source>This displays the package for which you want to search related packages for. Enter the package under the &quot;Related&quot; section.</source>
         <translation>Hier wird das Paket angezeigt zu dem ähnliche Pakete gesucht werden. Das Paket kann in der Sektion &quot;Ähnliche&quot; ausgewählt werden.</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedfeedbackwidget.ui" line="53"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedfeedbackwidget.h" line="80"/>
         <source>Clear</source>
         <translation>Löschen</translation>
     </message>
@@ -202,26 +220,31 @@ Anschließend können Sie den debtags-Plugin unter &quot;Packagesearch&quot; -&g
     <name>RelatedInput</name>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="14"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="108"/>
         <source>Form1</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="26"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="109"/>
         <source>Similar to package</source>
         <translation>Ähnlich zu Paket</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="51"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="110"/>
         <source>Result packages</source>
         <translation>Anzahl der Pakete</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="58"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="112"/>
         <source>Number of result packages</source>
         <translation>Anzahl der Pakete die die Ähnlichkeitssuche zurückgeben soll</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="61"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="115"/>
         <source>Defines the number of the most similar packages which will be displayed.</source>
         <translation>Anzahl der ähnlichsten Pakete die von der Suche zurückgegeben werden sollen.</translation>
     </message>
@@ -241,11 +264,13 @@ Or more formal: &lt;br&gt;
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="103"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="118"/>
         <source>Clear realated search</source>
         <translation>Ähnlichkeitssuche löschen</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/relatedinput.ui" line="106"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_relatedinput.h" line="120"/>
         <source>Clear</source>
         <translation>Löschen</translation>
     </message>
@@ -254,31 +279,37 @@ Or more formal: &lt;br&gt;
     <name>TagChooserWidget</name>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="16"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="61"/>
         <source>Form1</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="28"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="62"/>
         <source>Show packages with these tags</source>
         <translation>Pakete mit diesen Tags anzeigen</translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="35"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="64"/>
         <source>Check this to be able to exclude some tags</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="38"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="67"/>
         <source>Check this if you want to exclude some tags. If you check it, a list of tags will be shown. There you can select which to exclude.</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="41"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="69"/>
         <source>Exclude Tags</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../plugins/debtagsplugin/tagchooserwidget.ui" line="48"/>
+        <location filename="../plugins/debtagsplugin/debtagsplugin_autogen/include/ui_tagchooserwidget.h" line="70"/>
         <source>but not these tags</source>
         <translation></translation>
     </message>
